@@ -18,13 +18,19 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkantiddos_public.endpoint import endpoint_data
 
 class DescribeDdosCountRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'antiddos-public', '2017-05-18', 'DescribeDdosCount')
+		RpcRequest.__init__(self, 'antiddos-public', '2017-05-18', 'DescribeDdosCount','ddosbasic')
 		self.set_method('POST')
 
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 	def get_DdosRegionId(self): # String
 		return self.get_query_params().get('DdosRegionId')
 
